Field class
- Inheritance
-
- Object
- SuperModel
- Field
Constructors
- Field({String name = '', String type = '', String defaultValue = ''})
-
const
- Field.fromDynamic(dynamic source)
-
factory
Properties
- defaultValue → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
copyWith(
Map< String, dynamic> data) → Field -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited