Stub class
- Inheritance
-
- Object
- SuperModel
- Stub
Constructors
- Stub({dynamic superModelStub, dynamic modelStub, dynamic controllerStub, dynamic serviceStub, dynamic httpClientStub})
- Stub.fromDynamic(dynamic source)
-
factory
Properties
- controllerStub ↔ String
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClientStub ↔ String
-
latefinal
- modelStub ↔ String
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceStub ↔ String
-
latefinal
- superModelStub ↔ String
-
latefinal
Methods
-
copyWith(
Map< String, dynamic> data) → Stub -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited